W

Struct W 

pub struct W(/* private fields */);
Register SEQ_PROGRAM_CTL_0 writer

Implementations

Source

impl W

pub fn cycles(&mut self) -> CYCLES_W<'_, 0>

Bits 0:9 - Number of IP clock cycles (minus 1). This field is in the range of [0, 1023], allowing for a time of [1, 1024] IP clock cycles.

pub fn strobe_a(&mut self) -> STROBE_A_W<'_, 16>

Bit 16 - Specifies value of eFUSE control signal strobe_a

pub fn strobe_b(&mut self) -> STROBE_B_W<'_, 17>

Bit 17 - Specifies value of eFUSEcontrol signal strobe_b

pub fn strobe_c(&mut self) -> STROBE_C_W<'_, 18>

Bit 18 - Specifies value of eFUSE control signal strobe_c

pub fn strobe_d(&mut self) -> STROBE_D_W<'_, 19>

Bit 19 - Specifies value of eFUSE control signal strobe_d

pub fn strobe_e(&mut self) -> STROBE_E_W<'_, 20>

Bit 20 - Specifies value of eFUSE control signal strobe_e

pub fn strobe_f(&mut self) -> STROBE_F_W<'_, 21>

Bit 21 - Specifies value of eFUSE control signal strobe_f

pub fn strobe_g(&mut self) -> STROBE_G_W<'_, 22>

Bit 22 - Specifies value of eFUSE control signal strobe_g

pub fn done(&mut self) -> DONE_W<'_, 31>

Bit 31 - When set to 1 indicates that the Read cycle ends when the current cycle count reaches 0.

pub unsafe fn bits(&mut self, bits: u32) -> &mut Self

Writes raw bits to the register.

Methods from Deref<Target = W<SEQ_PROGRAM_CTL_0_SPEC>>

pub unsafe fn bits(&mut self, bits: REG::Ux) -> &mut Self

Writes raw bits to the register.

Safety

Read datasheet or reference manual to find what values are allowed to pass.